import sys
import typing

GenericType = typing.TypeVar("GenericType")


def complete(line, cursor, namespace):
    ...


def get_argspec(func, strip_self, doc, source):
    ...


def get_doc(obj):
    ...


def reduce_newlines(text):
    ...


def reduce_spaces(text):
    ...
