import sys
import typing

GenericType = typing.TypeVar("GenericType")


def draw_entry(display_keymaps, entry, col, level):
    ...


def draw_filtered(display_keymaps, filter_type, filter_text, layout):
    ...


def draw_hierarchy(display_keymaps, layout):
    ...


def draw_keymaps(context, layout):
    ...


def draw_km(display_keymaps, kc, km, children, layout, level):
    ...


def draw_kmi(display_keymaps, kc, km, kmi, layout, level):
    ...
