import sys
import typing

GenericType = typing.TypeVar("GenericType")


def check(check_ctxt, msgs, key, msgsrc, settings):
    ...


def dump_addon_bl_info(msgs, reports, module, settings):
    ...


def dump_addon_messages(module_name, do_checks, settings):
    ...


def dump_asset_messages(msgs, reports, settings):
    ...


def dump_messages(do_messages, do_checks, settings):
    ...


def dump_preset_messages(msgs, reports, settings):
    ...


def dump_py_messages(msgs, reports, addons, settings, addons_only):
    ...


def dump_py_messages_from_files(msgs, reports, files, settings):
    ...


def dump_rna_messages(msgs, reports, settings, verbose):
    ...


def dump_src_messages(msgs, reports, settings):
    ...


def dump_template_messages(msgs, reports, settings):
    ...


def init_spell_check(settings, lang):
    ...


def main():
    ...


def print_info(reports, pot):
    ...


def process_msg(msgs, msgctxt, msgid, msgsrc, reports, check_ctxt, settings):
    ...
