import sys
import typing

GenericType = typing.TypeVar("GenericType")


def keyconfig_data_oskey_from_ctrl(keyconfig_data_src, filter_fn):
    ...


def keyconfig_data_oskey_from_ctrl_for_macos(keyconfig_data_src):
    ...
