import sys
import typing

GenericType = typing.TypeVar("GenericType")


class DataPathBuilder:
    data_path: typing.Any

    def resolve(self, real_base, rna_update_from_map, fcurve, log):
        ...


def anim_data_actions(anim_data):
    ...


def classes_recursive(base_type, clss):
    ...


def find_path_new(id_data, data_path, rna_update_from_map, fcurve, log):
    ...


def id_iter():
    ...


def update_data_paths(rna_update, log):
    ...
