import sys
import typing
import bpy_types
import bl_ui.properties_grease_pencil_common
import bl_ui.space_toolsystem_common

GenericType = typing.TypeVar("GenericType")


class BoneOptions:
    def draw(self, context):
        ...


class ShowHideMenu:
    bl_label: typing.Any

    def draw(self, _context):
        ...


class TOPBAR_MT_edit_armature_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class TOPBAR_MT_edit_curve_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class TOPBAR_PT_annotation_layers(
        bpy_types.Panel, bpy_types._GenericUI,
        bl_ui.properties_grease_pencil_common.AnnotationDataPanel):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def draw_layers(self, context, layout, gpd):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class TOPBAR_PT_gpencil_materials(
        bl_ui.properties_grease_pencil_common.GreasePencilMaterialsPanel,
        bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class TOPBAR_PT_gpencil_vertexcolor(
        bl_ui.properties_grease_pencil_common.GreasePencilVertexcolorPanel,
        bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_AST_sculpt_brushes(bpy_types.AssetShelf):
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def as_pointer(self):
        ...

    def asset_poll(self, asset):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_HT_header(bpy_types.Header, bpy_types._GenericUI):
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_xform_template(self, layout, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_HT_tool_header(bpy_types.Header, bpy_types._GenericUI):
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_mode_settings(self, context):
        ...

    def draw_tool_settings(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_armature_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_armature_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_assign_material(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_bone_collections(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_brush_paint_modes(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_camera_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_curve_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_draw_gpencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_armature(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_armature_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_armature_names(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_armature_parent(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_armature_roll(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_clean(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_ctrlpoints(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_segments(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curves(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curves_select_more_less(bpy_types.Menu,
                                             bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_font(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_font_chars(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_font_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_font_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_font_kerning(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil_point(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil_showhide(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil_stroke(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_gpencil_transform(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil_animation(bpy_types.Menu,
                                            bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil_point(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil_showhide(bpy_types.Menu,
                                           bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_greasepencil_stroke(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_lattice(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_lattice_context_menu(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_clean(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_edges(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_extrude(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_faces(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_faces_data(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_merge(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_normals(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_normals_average(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_normals_select_strength(bpy_types.Menu,
                                                  bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_normals_set_strength(bpy_types.Menu,
                                               bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_by_trait(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_linked(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_loops(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_mode(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_more_less(bpy_types.Menu,
                                           bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_select_similar(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_shading(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_split(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_vertices(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_weights(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_meta(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_meta_showhide(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_metaball_context_menu(bpy_types.Menu,
                                           bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_pointcloud(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_surface(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_face_sets(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_face_sets_init(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_gpencil_animation(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_gpencil_autoweights(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_gpencil_edit_context_menu(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_gpencil_simplify(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_gpencil_vertex_group(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_grease_pencil_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_greasepencil_edit_context_menu(bpy_types.Menu,
                                               bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_greasepencil_material_active(bpy_types.Menu,
                                             bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_hook(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_image_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_light_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_context: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_lightprobe_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_make_links(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_make_single_user(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_mesh_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_metaball_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_mirror(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object(bpy_types.Menu, bpy_types._GenericUI):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_animation(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_apply(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_asset(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_cleanup(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_clear(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_collection(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_constraints(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_convert(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_liboverride(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_mode_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_parent(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_quick_effects(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_relations(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_rigid_body(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_shading(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_showhide(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_object_track(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_orientations_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_paint_gpencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_paint_grease_pencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_paint_vertex(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_paint_weight(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_generic(self, layout, is_editmode):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_paint_weight_lock(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_particle(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_particle_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pivot_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_apply(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_constraints(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_ik(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_motion(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_names(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_propagate(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_slide(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_transform(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_proportional_editing_falloff_pie(bpy_types.Menu,
                                                 bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_random_mask(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_automasking_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_curves(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_face_sets_edit_pie(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_gpencil_automasking_pie(bpy_types.Menu,
                                               bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_mask_edit_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_sculpt_set_pivot(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_armature(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_curve(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_curves(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_gpencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_grease_pencil(bpy_types.Menu,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_lattice(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_mesh(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_metaball(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_point_cloud(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_surface(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_edit_text(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_object(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_object_more_less(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_paint_mask(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_paint_mask_vertex(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_particle(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_pose(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_pose_more_less(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_select_sculpt_curves(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_shading_ex_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_shading_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_snap_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_surface_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_transform_base:
    bl_category: typing.Any
    bl_label: typing.Any

    def draw(self, context):
        ...


class VIEW3D_MT_transform_gizmo_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_uv_map(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_vertex_group(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_align(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_align_selected(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_cameras(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_local(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_navigation(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_regions(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_view_viewpoint(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_volume_add(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_weight_gpencil(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_wpaint_vgroup_lock_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_active_tool(
        bpy_types.Panel, bpy_types._GenericUI,
        bl_ui.space_toolsystem_common.ToolActivePanelHelper):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_active_tool_duplicate(
        bpy_types.Panel, bpy_types._GenericUI,
        bl_ui.space_toolsystem_common.ToolActivePanelHelper):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_annotation_onion(
        bl_ui.properties_grease_pencil_common.AnnotationOnionSkin,
        bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_collections(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_context_properties(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_curves_sculpt_add_shape(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_curves_sculpt_grow_shrink_scaling(bpy_types.Panel,
                                                  bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_curves_sculpt_parameter_falloff(bpy_types.Panel,
                                                bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gizmo_display(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_curve_edit(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_draw_context_menu(bpy_types.Panel,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_guide(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_lock(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_multi_frame(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_origin(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_sculpt_automasking(bpy_types.Panel,
                                           bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_sculpt_context_menu(bpy_types.Panel,
                                            bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_vertex_context_menu(bpy_types.Panel,
                                            bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_gpencil_weight_context_menu(bpy_types.Panel,
                                            bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_grease_pencil(
        bl_ui.properties_grease_pencil_common.AnnotationDataPanel,
        bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def draw_layers(self, context, layout, gpd):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_object_type_visibility(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_ex(self, _context, view, show_select):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_bones(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def is_using_wireframe(self, context):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_curve(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_mesh(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_mesh_freestyle(bpy_types.Panel,
                                            bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_mesh_measurement(bpy_types.Panel,
                                              bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_mesh_normals(bpy_types.Panel,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_edit_mesh_shading(bpy_types.Panel,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_geometry(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_gpencil_options(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_grease_pencil_options(bpy_types.Panel,
                                              bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_guides(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_motion_tracking(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_object(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_sculpt(bpy_types.Panel, bpy_types._GenericUI):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_sculpt_curves(bpy_types.Panel, bpy_types._GenericUI):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_texture_paint(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_vertex_paint(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_viewer_node(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_overlay_weight_paint(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_paint_texture_context_menu(bpy_types.Panel,
                                           bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_paint_vertex_context_menu(bpy_types.Panel,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_paint_weight_context_menu(bpy_types.Panel,
                                          bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_proportional_edit(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_quad_view(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_sculpt_automasking(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_sculpt_context_menu(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def get_shading(self, context):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_color(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_compositor(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_order: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_lighting(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_options(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_options_shadow(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_options_ssao(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_shading_render_pass(bpy_types.Panel, bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_snapping(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_transform_orientations(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_view3d_cursor(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_view3d_lock(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_view3d_properties(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_view3d_stereo(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_viewport_debug(bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class _draw_tool_settings_context_mode:
    def PAINT_GPENCIL(self, context, layout, tool):
        ...

    def PAINT_GREASE_PENCIL(self, context, layout, tool):
        ...

    def PAINT_TEXTURE(self, context, layout, tool):
        ...

    def PAINT_VERTEX(self, context, layout, tool):
        ...

    def PAINT_WEIGHT(self, context, layout, tool):
        ...

    def PARTICLE(self, context, layout, tool):
        ...

    def SCULPT(self, context, layout, tool):
        ...

    def SCULPT_CURVES(self, context, layout, tool):
        ...

    def SCULPT_GPENCIL(self, context, layout, tool):
        ...

    def VERTEX_GPENCIL(self, context, layout, tool):
        ...

    def WEIGHT_GPENCIL(self, context, layout, tool):
        ...


class VIEW3D_MT_bone_options_disable(bpy_types.Menu, bpy_types._GenericUI,
                                     BoneOptions):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    type: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_bone_options_enable(bpy_types.Menu, bpy_types._GenericUI,
                                    BoneOptions):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    type: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_bone_options_toggle(bpy_types.Menu, bpy_types._GenericUI,
                                    BoneOptions):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    type: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_curve_showhide(ShowHideMenu, bpy_types.Menu,
                                    bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_edit_mesh_showhide(ShowHideMenu, bpy_types.Menu,
                                   bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_particle_showhide(ShowHideMenu, bpy_types.Menu,
                                  bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_pose_showhide(ShowHideMenu, bpy_types.Menu,
                              bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_transform(VIEW3D_MT_transform_base, bpy_types.Menu,
                          bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_transform_armature(VIEW3D_MT_transform_base, bpy_types.Menu,
                                   bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_MT_transform_object(VIEW3D_MT_transform_base, bpy_types.Menu,
                                 bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


def draw_curve(_context):
    ...


def draw_gpencil_layer_active(context, layout):
    ...


def draw_gpencil_material_active(context, layout):
    ...
